@@ -1,6 +1,7 @@
 import sys
 sys.path.append("../")
 from datetime import datetime
+from asyncio import new_event_loop
 
 from chessdotcom.client import *
 from chessdotcom import ChessDotComResponse
@@ -8,6 +9,8 @@ from chessdotcom import ChessDotComResponse
 def test_endpoints(print_ = False, break_ = False):
 
     Client.config['headers']['user-agent'] = 'chess.com wrapper testing scripts. Contact me at saradzhyanartur@gmail.com'
+    Client.loop = new_event_loop()
+
 
     data = get_player_profile("fabianocaruana")
     assert(isinstance(data, ChessDotComResponse))
@@ -36,14 +39,14 @@ def test_endpoints(print_ = False, break_ = False):
     if break_:
         input()
 
-    data = is_player_online("fabianocaruana")
-    assert(isinstance(data, ChessDotComResponse))
-    print(data.__dict__.keys())
-    assert(len(data.__dict__.keys()) == 3)
-    if print_:
-        print(data)
-    if break_:
-        input()
+    # data = is_player_online("fabianocaruana")
+    # assert(isinstance(data, ChessDotComResponse))
+    # print(data.__dict__.keys())
+    # assert(len(data.__dict__.keys()) == 3)
+    # if print_:
+    #     print(data)
+    # if break_:
+    #     input()
 
     data = get_player_current_games("fabianocaruana")
     assert(isinstance(data, ChessDotComResponse))
